@@ -1,4 +1,7 @@
 use super::exceptions::Exceptions;
+use byte_unit::{Byte, ByteUnit};
+pub use bytes::ByteConversion;
+use core::time::Duration;
 use path_absolutize::*;
 use regex::Regex;
 use sha1::{Digest, Sha1};
@@ -11,11 +14,30 @@ use std::path::Path;
 pub use string::Str;
 pub use sum::Sum;
 pub use sum::SumTypes;
+pub use time::Timestamps;
 
+pub mod bytes;
 pub mod path;
 pub mod regexp;
 pub mod string;
 pub mod sum;
+pub mod time;
+
+impl bytes::ByteConversion for super::Interpreter {
+    fn convert(&self, from: u128, to: ByteUnit) -> f64 {
+        // get size in format needed, then get str & convert it to chars
+        let str = format!("{}", Byte::from_bytes(from).get_adjusted_unit(to));
+        let mut str_chars = str.chars();
+
+        // remove size label
+        for _ in 0..3 {
+            str_chars.next_back();
+        }
+
+        // convert to u128 & return
+        str_chars.as_str().parse::<f64>().unwrap()
+    }
+}
 
 impl path::Path for super::Interpreter {
     fn exist(&self, input: &str) -> bool {
@@ -119,3 +141,39 @@ impl Sum for super::Interpreter {
         buffer
     }
 }
+
+impl time::Timestamps for super::Interpreter {
+    fn get_date(&self, timestamp: Duration) -> String {
+        let chrono_duration = chrono::Duration::from_std(timestamp).unwrap();
+        let unix = chrono::naive::NaiveDateTime::from_timestamp(0, 0);
+        let naive = unix + chrono_duration;
+
+        // remove hour
+        let str = format!("{:?}", naive);
+        let mut str_chars = str.chars();
+        for _ in 0..19 {
+            str_chars.next_back();
+        }
+
+        str_chars.as_str().to_string()
+    }
+    fn get_hour(&self, timestamp: Duration) -> String {
+        let chrono_duration = chrono::Duration::from_std(timestamp).unwrap();
+        let unix = chrono::naive::NaiveDateTime::from_timestamp(0, 0);
+        let naive = unix + chrono_duration;
+
+        // remove date
+        let str = format!("{:?}", naive);
+        let mut str_chars = str.chars();
+        for _ in 0..12 {
+            str_chars.next();
+        }
+
+        // remove ms
+        for _ in 0..10 {
+            str_chars.next_back();
+        }
+
+        str_chars.as_str().to_string()
+    }
+}
