@@ -1,11 +1,28 @@
 use super::*;
 
 pub trait Conditionals {
+    fn get_conditionals(&mut self) -> Vec<Conditional>;
     fn parse_next_conditional(&mut self) -> super::Conditional;
     fn reset_conditionals(&mut self);
 }
 
 impl Conditionals for super::Parser {
+    fn get_conditionals(&mut self) -> Vec<Conditional> {
+        let mut conditionals: Vec<Conditional> = vec![];
+        loop {
+            // get conditional and send it to the vector
+            let conditional: Conditional = self.parse_next_conditional();
+            conditionals.push(conditional.clone());
+            // conditionals will stop when the condr of the next is null,
+            // so then we stop
+            if conditional.next_conditional_relationship.is_none() {
+                break;
+            }
+        }
+
+        println_on_debug!("  Conditionals {:#?}", &conditionals);
+        conditionals
+    }
     fn parse_next_conditional(&mut self) -> Conditional {
         // We reset from previous execution, if we do not do it, the next
         // for-loop will not know what to do
@@ -23,7 +40,7 @@ impl Conditionals for super::Parser {
             let last_token: &Token = &self.tokens[i - (i != 0usize) as usize];
 
             // this way we know whenever a value has been already parsed
-            if let None = self.val1 {
+            if self.val1.is_none() {
                 println_on_debug!("  parsing val1, token {token}, next token {next_token}");
 
                 // convert it to a literal, if was not converted successfully,
@@ -41,7 +58,7 @@ impl Conditionals for super::Parser {
                     },
                     _ => Some(literal_val1.unwrap()),
                 };
-            } else if let None = self.oper {
+            } else if self.oper.is_none() {
                 println_on_debug!("  parsing oper, token {token}, next token {next_token}");
 
                 // get sure the correct operator is being used
@@ -71,7 +88,7 @@ impl Conditionals for super::Parser {
                         Some(op.unwrap())
                     },
                 }
-            } else if let None = self.val2 {
+            } else if self.val2.is_none() {
                 println_on_debug!("  parsing val2, token {token}, next token {next_token}");
 
                 // convert it to a literal, if was not converted successfully,
@@ -89,7 +106,7 @@ impl Conditionals for super::Parser {
                     },
                     _ => Some(literal_val2.unwrap()),
                 };
-            } else if let None = self.rela {
+            } else if self.rela.is_none() {
                 println_on_debug!("  parsing rela, token {token}, next token {next_token}");
 
                 // if error, exit, else, continue. simple
@@ -129,10 +146,9 @@ impl Conditionals for super::Parser {
                 self.raise_parse_error("EXPECTED VALUE", String::from("Found nothing"));
             }),
             next_conditional_relationship: self.rela.clone(),
-            position: self.position.clone(),
+            position: self.position,
         }
     }
-
     // this way the conditional's parser knows whenever it has to parse a new conditional
     fn reset_conditionals(&mut self) {
         self.val1 = None;
